@@ -2,37 +2,9 @@
 #
 #   file: lib/Dist/Zilla/PluginBundle/Author/VDB.pm
 
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Dist-Zilla-PluginBundle-Author-VDB.
-#pod
-#pod perl-Dist-Zilla-PluginBundle-Author-VDB is free software: you can redistribute it and/or modify
-#pod it under the terms of the GNU General Public License as published by the Free Software
-#pod Foundation, either version 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Dist-Zilla-PluginBundle-Author-VDB is distributed in the hope that it will be useful, but
-#pod WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-#pod PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Dist-Zilla-PluginBundle-Author-VDB. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
 
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-#pod =head1 DESCRIPTION
-#pod
-#pod It is unlikely that someone else will want to use it, so I will not bother with documenting it, at
-#pod least for now.
-#pod
-#pod =for Pod::Coverage configure
-#pod
-#pod =cut
 
 package Dist::Zilla::PluginBundle::Author::VDB;
 
@@ -42,11 +14,31 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-use Dist::Zilla::Plugin::Hook 0.004;    # TODO: Bump it to 0.005 when it is released!
+use Dist::Zilla::Plugin::Hook 0.005;    # We need Hook::PrereqSource.
+
+has minimum_perl => (
+    is          => 'ro',
+    isa         => 'Str',
+    lazy        => 1,
+    default     => sub {
+        my ( $self ) = @_;
+        return $self->payload->{ minimum_perl } // '5.006';
+    },
+);
+
+has fake_release => (
+    is          => 'ro',
+    isa         => 'Bool',
+    lazy        => 1,
+    default     => sub {
+        my ( $self ) = @_;
+        return $self->payload->{ fake_release } // $ENV{ FAKE_RELEASE };
+    },
+);
 
 sub configure {
 
@@ -162,6 +154,7 @@ sub configure {
         # Code
 
         [ 'Test::Compile' ],
+            #fake_home => 1 ???
 
         [ 'Test::Version' => {          # All modules have version.
             #~ 'is_strict' => 1,        # Does not work for trial releases.
@@ -169,7 +162,7 @@ sub configure {
 
         [ 'Test::NewVersion' ],         # This is not a version already uploaded to CPAN.
         [ 'Test::MinimumVersion' => {
-            'max_target_perl' => 5.006, # TODO: Parametrize it.
+            'max_target_perl' => $self->minimum_perl,
         } ],
 
         [ 'Test::Fix' . 'me' ],
@@ -214,11 +207,10 @@ sub configure {
         #
 
         [ 'MinimumPerl' ],
+
         [ 'AutoPrereqs' ],
+        # [Prereqs::AuthorDeps]
 
-    );
-
-    $self->add_plugins(
         [ 'Hook::PrereqSource' => {
             'hook' => [
                 #   `use autodie ':all';` implicitly requires `IPC::System::Simple` module, but
@@ -238,23 +230,20 @@ sub configure {
                 q| };                                                                         |,
             ],
         } ],
-    ) if version->parse( Dist::Zilla::Plugin::Hook->VERSION ) > version->parse( '0.004' );
-        # ^ TODO: Drop condition whern 0.005 released.
-
-    $self->add_plugins(
 
         [ 'CheckPrereqsIndexed'   ],    # Make sure all prereqs are published in CPAN.
 
         [ 'MetaProvides::Package' ],
 
         [ 'MetaResources::Template' => {
-            'homepage'            => 'https://metacpan.org/release/Dist-Zilla-PluginBundle-Author-VDB',
-            'license'             => 'http://www.gnu.org/licenses/gpl-3.0.txt',
-            'repository.type'     => 'hg',
-            'repository.url'      => 'https://vandebugger.fedorapeople.org/hg/perl-Dist-Zilla-PluginBundle-Author-VDB',
-            'repository.web'      => '',
-            'bugtracker.mailto'   => 'mailto:bug-Dist-Zilla-PluginBundle-Author-VDB@rt.cpan.org',
-            'bugtracker.web'      => 'https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-Author-VDB',
+            'delimiters'          => '{ }',
+            'homepage'            => '{$MY::metacpan}',
+            'license'             => '{$dist->license->url}',
+            'repository.type'     => '{$MY::repo_type}',
+            'repository.url'      => '{$MY::repo_url}',
+            'repository.web'      => '{$MY::repo_web}',
+            'bugtracker.mailto'   => '{$MY::cpan_rt_mailto}',
+            'bugtracker.web'      => '{$MY::cpan_rt_browse}',
         } ],
 
         [ 'MetaYAML' ],                 # Generate `META.yml`.
@@ -274,6 +263,7 @@ sub configure {
         #~ [ 'RunExtraTests' ],          ; Does not work for me, see <https://github.com/dagolden/Dist-Zilla-Plugin-CheckExtraTests/issues/26>.
 
         [ 'CheckExtraTests' ],          # So use CheckExtraTest meanwhile.
+        #~ [CheckChangesHasContent]
 
         [ 'TestRelease'     ],          # Unpack tarball and run tests.
 
@@ -321,7 +311,7 @@ sub configure {
 
         [ 'ConfirmRelease' ],       # Ask confirmation before uploading the release.
 
-        [ 'UploadToCPAN'   ],
+        [ $self->fake_release ? 'FakeRelease' : 'UploadToCPAN' ],
 
         [ 'Hook::AfterRelease' => 'hg add tag' => {
             'hook' => [
@@ -341,9 +331,12 @@ sub configure {
             ],
         } ],
 
-        [ 'ArchiveRelease' => {
-            'directory'   => '.releases',
-        } ],
+        $self->fake_release ? (
+        ) : (
+            [ 'ArchiveRelease' => {
+                'directory'   => '.releases',
+            } ],
+        ),
 
         [ 'NextRelease' => {
             'format'      => '%V @ %{yyyy-MM-dd HH:mm zzz}d',
@@ -368,10 +361,20 @@ sub configure {
 
         [ 'Hook::AfterRelease' => 'hg push' => {
             'hook' => [
-                q| use IPC::System::Simple 'capture';    |,
-                q| my @stdout = capture( 'hg', 'push' ); |,
-                q| chomp( @stdout );                     |,
-                q| $self->log( "    $_" ) for @stdout;   |,
+                $self->fake_release ? (
+                    q| $self->log( 'Fake release, skipping "hg push"...' ); |,
+                ) : (
+                    q| use IPC::System::Simple 'capture';    |,
+                    q| my @stdout = capture( 'hg', 'push' ); |,
+                    q| chomp( @stdout );                     |,
+                    q| $self->log( "    $_" ) for @stdout;   |,
+                ),
+            ],
+        } ],
+
+        [ 'Hook::AfterRelease' => 'clean' => {
+            'hook' => [
+                q| $zilla->clean(); |,
             ],
         } ],
 
@@ -387,26 +390,10 @@ __PACKAGE__->meta->make_immutable();
 
 # doc/what.pod #
 
-#pod =encoding UTF-8
-#pod
-#pod =head1 WHAT?
-#pod
-#pod C<Dist-Zilla-PluginBundle-Author-VDB> (or just C<@Author::VDB>) is a C<Dist-Zilla> plugin bundle used by VDB.
-#pod
-#pod =cut
 
 # end of file #
 # doc/why.pod #
 
-#pod =encoding UTF-8
-#pod
-#pod =head1 WHY?
-#pod
-#pod I have published few distributions on CPAN. Every distribution have F<dist.ini> file. All the
-#pod F<dist.ini> files are very similar. Maintaining multiple very similar F<dist.ini> files is boring.
-#pod Plugin bundle solves the problem.
-#pod
-#pod =cut
 
 # end of file #
 
@@ -425,7 +412,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version 0.001, released on 2015-08-07 15:42 UTC.
+Version 0.002, released on 2015-08-08 17:03 UTC.
 
 =head1 WHAT?
 
@@ -436,6 +423,20 @@ C<Dist-Zilla-PluginBundle-Author-VDB> (or just C<@Author::VDB>) is a C<Dist-Zill
 It is unlikely that someone else will want to use it, so I will not bother with documenting it, at
 least for now.
 
+=head1 OPTIONS
+
+=head2 minimum_perl
+
+=head2 fake_release
+
+If true (C<1>), release will be a fake one, i. e. no external operations will be done:
+C<UploadToCPAN> plugin will be replaced with C<FakeRelease> (which does nothing), C<ArchiveRelease>
+will be skipped, and C<hg push> will not be performed.
+
+Option can be set trough F<dist.ini> file or with C<FAKE_RELEASE> environment variable.
+
+C<Bool>, optional, default value is C<0>.
+
 =head1 WHY?
 
 I have published few distributions on CPAN. Every distribution have F<dist.ini> file. All the
